@@ -1,4 +1,7 @@
 pyref = object()
+nspoint = object()
+nssize = object()
+nsrect = object()
 
 def objcname(name):
     def decorator(func):
